NovaCheckbox class
A styled checkbox widget for Nova UI.
Supports rounded, circle, and square shapes with theme-aware colors, label, sublabel, and indeterminate state.
Example:
// Simple checkbox
NovaCheckbox(
value: _checked,
label: 'Accept terms',
onChanged: (v) => setState(() => _checked = v!),
)
// With sublabel
NovaCheckbox(
value: _checked,
label: 'Marketing emails',
sublabel: 'Receive updates about new features',
onChanged: (v) => setState(() => _checked = v!),
)
// Circle shape
NovaCheckbox(
value: _checked,
label: 'Remember me',
shape: NovaCheckboxShape.circle,
onChanged: (v) => setState(() => _checked = v!),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- NovaCheckbox
Constructors
- NovaCheckbox({Key? key, required bool? value, required void onChanged(bool?), String? label, String? sublabel, NovaCheckboxShape shape = NovaCheckboxShape.rounded, Color? activeColor, bool enabled = true, bool tristate = false})
-
Creates a NovaCheckbox widget.
const
Properties
- activeColor → Color?
-
Override check color. Defaults to theme primary.
final
- enabled → bool
-
When false, checkbox is non-interactive and visually dimmed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
Primary label shown beside the checkbox.
final
- onChanged → void Function(bool?)
-
Called when the checkbox value changes.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → NovaCheckboxShape
-
Shape of the checkbox. Defaults to rounded.
final
- sublabel → String?
-
Secondary smaller text shown below label.
final
- tristate → bool
-
When true, supports checked/unchecked/indeterminate states.
final
- value → bool?
-
Whether the checkbox is checked.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited